adviz
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

Get startd quickly and see exmaples below

## Install

``` bash
python3 -m pip install adviz
```

## Explore the available visualizations
